@@ -1,10 +1,11 @@
 package Twitter::API::Trait::ApiMethods;
 # ABSTRACT: Convenient API Methods
-$Twitter::API::Trait::ApiMethods::VERSION = '0.0109';
+$Twitter::API::Trait::ApiMethods::VERSION = '0.0110';
 use 5.14.1;
 use Carp;
 use Moo::Role;
 use MooX::Aliases;
+use Ref::Util qw/is_hashref is_ref/;
 use namespace::clean;
 
 requires 'request';
@@ -644,7 +645,7 @@ alias trends_location => 'trends_place';
 my $rename_category = sub {
     my $self = shift;
 
-    my $args = ref $_[-1] eq 'HASH' ? pop : {};
+    my $args = is_hashref($_[-1]) ? pop : {};
     $args->{slug} = delete $args->{category} if exists $args->{category};
     return ( @_, $args );
 };
@@ -798,22 +799,25 @@ sub create_media_metadata {
     my ( $self, $to_json ) = @_;
 
     croak 'expected a single hashref argument'
-        unless @_ == 2 && ref $_[1] eq 'HASH';
+        unless @_ == 2 && is_hashref($_[1]);
 
     $self->request(post => 'media/metadata/create', {
         -to_json => $to_json,
     });
 }
 
-#pod =method create_mute([ $id, ][ \%args ])
+#pod =method create_mute([ $screen_name | $user_id, ][ \%args ])
 #pod
 #pod L<https://dev.twitter.com/rest/reference/post/mutes/users/create>
 #pod
+#pod Alias: mute
+#pod
 #pod =cut
 
 sub create_mute {
-    shift->request_with_pos_args(id => post => 'mutes/users/create', @_);
+    shift->request_with_pos_args(':ID' => post => 'mutes/users/create', @_);
 }
+alias mute => 'create_mute';
 
 #pod =method create_saved_search([ $query, ][ \%args ])
 #pod
@@ -914,15 +918,18 @@ sub destroy_friend {
 }
 alias $_ => 'destroy_friend' for qw/unfollow destroy_friendship/;
 
-#pod =method destroy_mute([ $id, ][ \%args ])
+#pod =method destroy_mute([ $screen_name | $user_id, ][ \%args ])
 #pod
 #pod L<https://dev.twitter.com/rest/reference/post/mutes/users/destroy>
 #pod
+#pod Alias: unmute
+#pod
 #pod =cut
 
 sub destroy_mute {
-    shift->request_with_pos_args(id => post => 'mutes/users/destroy', @_);
+    shift->request_with_pos_args(':ID' => post => 'mutes/users/destroy', @_);
 }
+alias unmute => 'destroy_mute';
 
 #pod =method destroy_saved_search([ $id, ][ \%args ])
 #pod
@@ -1169,10 +1176,10 @@ sub upload_media {
     # Used to require media. Now requires media *or* media_data.
     # Handle either as a positional parameter, like we do with
     # screen_name or user_id on other methods.
-    if ( @_ && ref $_[0] ne 'HASH' ) {
+    if ( @_ && !is_hashref($_[0]) ) {
         my $media = shift;
-        my $key = ref $media ? 'media' : 'media_data';
-        my $args = @_ && ref $_[0] eq 'HASH' ? pop : {};
+        my $key = is_ref($media) ? 'media' : 'media_data';
+        my $args = @_ && is_hashref($_[0]) ? pop : {};
         $args->{$key} = $media;
         unshift @_, $args;
     }
@@ -1203,7 +1210,7 @@ Twitter::API::Trait::ApiMethods - Convenient API Methods
 
 =head1 VERSION
 
-version 0.0109
+version 0.0110
 
 =head1 DESCRIPTION
 
@@ -1579,10 +1586,12 @@ L<https://dev.twitter.com/rest/reference/post/lists/create>
 
 L<https://dev.twitter.com/rest/reference/post/media/metadata/create>
 
-=head2 create_mute([ $id, ][ \%args ])
+=head2 create_mute([ $screen_name | $user_id, ][ \%args ])
 
 L<https://dev.twitter.com/rest/reference/post/mutes/users/create>
 
+Alias: mute
+
 =head2 create_saved_search([ $query, ][ \%args ])
 
 L<https://dev.twitter.com/rest/reference/post/saved_searches/create>
@@ -1621,10 +1630,12 @@ Aliases: unfollow, destroy_friendship
 
 L<https://dev.twitter.com/rest/reference/post/friendships/destroy>
 
-=head2 destroy_mute([ $id, ][ \%args ])
+=head2 destroy_mute([ $screen_name | $user_id, ][ \%args ])
 
 L<https://dev.twitter.com/rest/reference/post/mutes/users/destroy>
 
+Alias: unmute
+
 =head2 destroy_saved_search([ $id, ][ \%args ])
 
 Aliases: delete_saved_search
