@@ -1,9 +1,10 @@
 package Twitter::API::Trait::Migration;
 # ABSTRACT: Migration support Net::Twitter/::Lite users
-$Twitter::API::Trait::Migration::VERSION = '0.0109';
+$Twitter::API::Trait::Migration::VERSION = '0.0110';
 use 5.14.1;
 use Carp;
 use Moo::Role;
+use Ref::Util qw/is_ref/;
 use namespace::clean;
 
 has [ qw/request_token request_token_secret/ ] => (
@@ -41,7 +42,7 @@ sub ua { shift->user_agent(@_) }
 
 sub _get_auth_url {
     my ( $self, $endpoint ) = splice @_, 0, 2;
-    my %args = @_ == 1 && ref $_[0] ? %{ $_[0] } : @_;
+    my %args = @_ == 1 && is_ref($_[0]) ? %{ $_[0] } : @_;
 
     my $callback = delete $args{callback} // 'oob';
     my ( $r, $c ) = $self->oauth_request_token(callback => $callback);
@@ -116,12 +117,12 @@ Twitter::API::Trait::Migration - Migration support Net::Twitter/::Lite users
 
 =head1 VERSION
 
-version 0.0109
+version 0.0110
 
 =head1 DESCRIPTION
 
 Twitter::API is a rewrite of L<Net::Twitter>. It's leaner, lighter, and
-faster—fewer dependencies, less baggage. This trait helps Net::Twitter and
+has faster—fewer dependencies, and less baggage. This trait helps Net::Twitter and
 Net::Twitter::Lite users migrate to Twitter::API by providing Net::Twitter
 compatible behavior where possible and warning politely where code should be
 changed.
@@ -234,7 +235,7 @@ Or for the smallest change to your code:
     $r->rate_limit_remaning; # same as before
 
 However, there is migration support for B<WrapResult>. Call the constructor
-with option C<<wrap_result => 1>> and Twitter::API will return the context
+with option C<< wrap_result => 1 >> and Twitter::API will return the context
 object, only, for API calls. This should give you the same behavior you had
 with B<WrapResult> while you modify your code. Twitter::API will warn when this
 option is used. You may disale warnings with
@@ -244,7 +245,7 @@ If you are using any other Net::Twitter traits, please contact the author of
 Twitter::API.  Additional traits may be added to Twitter::API or released as
 separate distributions.
 
-If you are using C<<decode_html_entities => 1>> in Net::Twitter, drop that
+If you are using C<< decode_html_entities => 1 >> in Net::Twitter, drop that
 option and add trait B<DecodeHtmlEntities>. Traits B<AppAuth> and
 B<RetryOnError> provide the same functionality in Twitter::API as their
 Net::Twitter counterparts. So, no changes required, there, if you're using
@@ -259,35 +260,35 @@ DecodeHtmlEntities.
 
 =head2 Other constructor options
 
-Drop option C<<ssl => 1>>. It is no longer necessary. By default, all
+Drop option C<< ssl => 1 >>. It is no longer necessary. By default, all
 connections use SSL.
 
 If you are setting B<useragent_lass> and/or B<useragent_args> to customize the
-user agent, just construct your own pass it to new with C<<user_agent =>
-$custom_user_agent>>.
+user agent, just construct your own pass it to new with C<< user_agent =>
+$custom_user_agent >>.
 
 If you are using B<ua> to set a custom user agent, the attribute name has
-changed to B<usre_agent>. So, pass it to new with C<<user_agent =>
-$custom_user_agent>>.
+changed to B<usre_agent>. So, pass it to new with C<< user_agent =>
+$custom_user_agent >>.
 
 By default, Twitter::API uses L<HTTP::Thin> as its user agent. You should be
-able to you any user agent you like, as long as it has a B<request> method that
+able to use any user agent you like, as long as it has a B<request> method that
 takes an L<HTTP::Request> and returns an L<HTTP::Response>.
 
 If you used B<clientname>, B<clientver>, B<clienturl>, or B<useragent>, see
 L<Twitter::API/agent> and L<Twitter::API/default_headers>. If all you're after
-is a custome User-Agent header, just pass C<<agent => $user_agent_string>>. It
-will be used for both User-Agent header and the X-Twitter-Client header on
+is a custom User-Agent header, just pass C<< agent => $user_agent_string >>.
+It will be used for both User-Agent header and the X-Twitter-Client header on
 requests. If you want to include your own application version and url, pass
-C<<default_headers => \%my_request_headers>>.
+C<< default_headers => \%my_request_headers >>.
 
 =head2 OAuth changes
 
 Net::Twitter saved request and access tokens in the client instance as part of
 the 3-legged OAuth handshake. That was a poor design decision. Twitter::API
 returns request and access tokens to the caller. It is the caller's
-responsibility to store are cache them appropriately. Hovever, tansitional
-support is provided, with client instance storage, so your code can run,
+responsibility to store and cache them appropriately. Hovever, transitional
+support is provided, with client instance storage, so your code can run
 unmodified while you make the transition.
 
 The following methods exist only for migration from Net::Twitter and will be
@@ -323,7 +324,7 @@ replace with L<oauth_access_token|Twitter::API/oauth_access_token>
 If you are using the B<AppAuth> trait, replace B<request_access_token> calls
 with B<oauth2_token> calls. Method B<oauth2_token> does not set the
 C<access_token> attribute. Method C<request_access_token> is provided for
-tranitional support, only. It warns like the OAuth mehods discussed above, and
+transitional support, only. It warns like the OAuth methods discussed above, and
 it sets the C<access_token> attribute so existing code should work as expected
 during migration. It will be removed in a future release.
 
